@@ -86,13 +86,34 @@ build_tt <- function(x, output = NULL) {
     x <- eval(l)
   }
 
+  if (x@output == "typst") {
+    if (is.null(x@theme[[1]]) || is.function(x@theme[[1]]) || isTRUE(x@theme[[1]] %in% c("default", "striped"))) {
+      # reverse the order of the lines to allow overwriting defaults
+      ls <- x@lazy_style 
+      x <- style_tt(x, i = nrow(x), line = "b", line_width = 0.1)
+      if (x@nhead > 0) {
+        x <- style_tt(x, i = -x@nhead + 1, line = "t", line_width = 0.1)
+        x <- style_tt(x, i = 1, line = "t", line_width = 0.05)
+      } else {
+        x <- style_tt(x, i = 1, line = "t", line_width = 0.1)
+      }
+    }
+  }
+
   if (!x@output %in% c("markdown", "gfm", "dataframe")) {
     for (l in x@lazy_style) {
       l[["x"]] <- x
-      x <- eval(l)
+      # output-specific styling
+      if (is.null(l$output) || isTRUE(x@output == l$output)) {
+        x <- eval(l)
+      }
     }
   }
 
+  if (x@output == "typst") {
+    x <- style_apply_typst(x)
+  }
+
   x <- finalize(x)
 
   x@table_string <- lines_drop_consecutive_empty(x@table_string)
