@@ -22,7 +22,7 @@ setMethod(
 group_typst_row <- function(x, i, indent, ...) {
   tab <- x@table_string
   tab <- strsplit(tab, split = "\\n")[[1]]
-  body_min <- utils::head(grep("tinytable cell content after", tab), 1) + x@nhead
+  body_min <- utils::head(grep("tinytable cell content after", tab), 1) + 1
   body_max <- utils::head(grep("end table", tab), 1) - 1
   body <- body_min:body_max
   top <- tab[1:(body_min - 1)]
@@ -38,8 +38,9 @@ group_typst_row <- function(x, i, indent, ...) {
   tab <- paste(tab, collapse = "\n")
   x@table_string <- tab
   idx_new <- i + seq_along(i) - 1
-  idx_old <- setdiff(seq_len(nrow(x)), idx_new)
-  x <- style_tt(x, idx_old, indent = indent)
+  idx_all <- seq_len(nrow(x) + length(i))
+  idx <- setdiff(idx_all, idx_new)
+  x <- style_tt(x, idx, indent = indent)
   return(x)
 }
 
