@@ -5,15 +5,11 @@ options(tinytable_print_output = "typst")
 
 
 # semi complicated
-# Q
-# pkgload::load_all()
 tab <- tt(mtcars[1:4, 1:5], caption = "Hello World") |>
   group_tt(j = list("Group 1" = 4:5, "Group 2" = 2:3)) |>
   style_tt(j = 1:5, align = "lcccr") |>
   style_tt(i = 2, j = 1:3, strikeout = TRUE, bold = TRUE, background = "black", color = "white") |>
   style_tt(j = 1, color = "red", italic = TRUE)
-# print(tab)
-
 expect_snapshot_print(tab, label = "typst-complicated")
 
 
@@ -97,6 +93,30 @@ tab <- tt(dat) |>
       "Hamburgers" = 1:3,
       "Halloumi" = 4:5,
       "Tofu" = 7))
-expect_snapshot_print(dat, label = "group_columns")
+expect_snapshot_print(dat, label = "typst-group_columns")
+
+
+# issue #323
+dat <- mtcars[1:9, 1:8]
+tab <- tt(dat) |> 
+  group_tt(
+    i = list("I like (fake) hamburgers" = 3,
+             "She prefers halloumi" = 4,
+             "They love tofu" = 7),
+    j = list("Hamburgers" = 1:3,
+             "Halloumi" = 4:5,
+             "Tofu" = 7)) |>
+  style_tt(
+    i = c(3, 5, 9),
+    align = "c",
+    background = "black",
+    color = "orange") |>
+  style_tt(i = -1, color = "orange")
+tab@output <- "typst"
+expect_snapshot_print(tab, label = "typst-issue323_group_tt_style_tt")
+
+
 
 options(tinytable_print_output = NULL)
+
+
